function [fig_out, axes_out, plot_out] = dm(w,varargin)
%-------help for gtk marker plot command dm--------------------------------
% Function Syntax: 
% [figureHandle_,axesHandle_,plotHandle_] = 
% DM(w,[property_name,property_value]) or
% DM(w,xlo,xhi) or
% DM(w,xlo,xhi,ylo,yhi) 
%
% Output: figure,axes and plot handle
% Input: 1d dataset object and other control parameters (name value pairs)
%
% you can also give axis limit for x and y 
% Purpose: plot the data according to values and control properties (for
% figure, axes and plot)
%
% Example: 
% DM(w) --> default structure plot
% DM(w,'Color','red') --> override default structure values 
% DM(w,'default','my_struct','Color','red') --> override values 
% DM(w,'default','my_struct') --> from structure
% DM(w,10,20)
% DM(w,10,20,0,200)
%--------------------------------------------------------------------------

%total
tot = numel(varargin);


if strcmp(class(w),'IXTdataset_2d')
    w=ixf_twod_to_oned(w);
end


if ( tot == 2)
    if (isnumeric(varargin{1}) && isnumeric(varargin{2}))
        [figureHandle_,axesHandle_,plotHandle_] = uib_plotgeneral(w,'m','xlim',[varargin{1},varargin{2}]);
    else
        [figureHandle_,axesHandle_,plotHandle_] = uib_plotgeneral(w,'m',varargin{:});
    end
elseif (tot == 4)
    if (isnumeric(varargin{1}) && isnumeric(varargin{2}) && isnumeric(varargin{3}) && isnumeric(varargin{4}))
        [figureHandle_,axesHandle_,plotHandle_] = uib_plotgeneral(w,'m','xlim',[varargin{1},varargin{2}],'ylim',[varargin{3},varargin{4}]);
    else
        [figureHandle_,axesHandle_,plotHandle_] = uib_plotgeneral(w,'m',varargin{:});
    end    
else
    [figureHandle_,axesHandle_,plotHandle_] = uib_plotgeneral(w,'m',varargin{:});    
end

if nargout > 0
    fig_out = figureHandle_;
    axes_out = axesHandle_;
    plot_out = plotHandle_;
end

